Dockalot Documentation
====================================

Welcome to the ``dockalot`` documentation. ``dockalot`` is a tool to build
Docker images using Ansible playbooks for application and configuration
installation. It addresses several shortcomings with the default Docker
toolkit to make building non-trivial images easier.


Contents:

.. toctree::
   :maxdepth: 2

   introduction
   config-reference


* :ref:`search`

